@@ -42,7 +42,7 @@ public:
     void setReadOnly(bool readOnly);
 
     void setLocalCustomFieldDescriptions(const QVariantList &descriptions);
-    QVariantList localCustomFieldDescriptions() const;
+    Q_REQUIRED_RESULT QVariantList localCustomFieldDescriptions() const;
 public Q_SLOTS:
     void slotAddNewField(const CustomField &field);
 
