@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -20,8 +20,8 @@
     02110-1301, USA.
 */
 
-#ifndef PHONEWIDGETTEST_H
-#define PHONEWIDGETTEST_H
+#ifndef MAILWIDGETTEST_H
+#define MAILWIDGETTEST_H
 
 #include <QObject>
 class MailWidgetTest : public QObject
@@ -34,4 +34,4 @@ private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // PHONEWIDGETTEST_H
+#endif // MAILWIDGETTEST_H
