@@ -68,10 +68,10 @@ public:
         font.setStyle(QFont::StyleItalic);
         QFontMetrics metrics(font);
         for (const QString &description : qAsConst(mDescriptions)) {
-            mMaxDescriptionWidth = qMax(mMaxDescriptionWidth, metrics.width(description));
+            mMaxDescriptionWidth = qMax(mMaxDescriptionWidth, metrics.boundingRect(description).width());
         }
 
-        mMaxDescriptionWidth += 3;
+        mMaxDescriptionWidth += 2;
     }
 
     int maximumDescriptionWidth() const
@@ -211,7 +211,7 @@ bool DisplayNameEditWidget::eventFilter(QObject *object, QEvent *event)
             QFontMetrics metrics(mView->font());
             const int viewCount(mView->count());
             for (int i = 0; i < viewCount; ++i) {
-                maxWidth = qMax(maxWidth, metrics.width(mView->itemText(i)));
+                maxWidth = qMax(maxWidth, metrics.boundingRect(mView->itemText(i)).width());
             }
 
             // resize it to show the complete content
@@ -244,7 +244,12 @@ void DisplayNameEditWidget::updateView()
     mView->setItemText(5, mContact.formattedName());
 
     // delay the state change here, since we might have been called from mView via a signal
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(this,  [this]() { setComboBoxEditable(mDisplayType == CustomName); }, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(this, "setComboBoxEditable", Qt::QueuedConnection, Q_ARG(bool, mDisplayType == CustomName));
+#endif
+
 
     mView->setCurrentIndex((int)mDisplayType);
 }
