@@ -30,7 +30,7 @@ class Addressee;
 namespace ContactEditor {
 namespace Utils {
 void splitCustomField(const QString &str, QString &app, QString &name, QString &value);
-QString loadCustom(const KContacts::Addressee &contact, const QString &key);
+Q_REQUIRED_RESULT QString loadCustom(const KContacts::Addressee &contact, const QString &key);
 void storeCustom(KContacts::Addressee &contact, const QString &key, const QString &value);
 }
 }
