@@ -50,7 +50,7 @@ public:
     QImage loadImage(const QUrl &url, bool *ok, bool selectPictureSize = true);
 
 private:
-    QWidget *mParent;
+    QWidget *mParent = nullptr;
 };
 
 ImageLoader::ImageLoader(QWidget *parent)
@@ -166,6 +166,7 @@ void ImageWidget::storeContact(KContacts::Addressee &contact) const
 void ImageWidget::setReadOnly(bool readOnly)
 {
     mReadOnly = readOnly;
+    setAcceptDrops(!mReadOnly);
 }
 
 void ImageWidget::updateView()
