@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -31,7 +31,7 @@ PreferredLineEditWidget::PreferredLineEditWidget(QWidget *parent)
     : KLineEdit(parent)
     , mPreferred(false)
 {
-    mIconEnabled = QIcon(QIcon::fromTheme(QStringLiteral("rating")));
+    mIconEnabled = QIcon::fromTheme(QStringLiteral("rating"));
     KIconLoader loader;
     QImage iconDisabled
         = mIconEnabled.pixmap(loader.currentSize(KIconLoader::Panel)).toImage();
